import os

import wandb

from .filters import if_notag, if_stale
from .utils import delete_run, delete_run_from_url, get_run_from_url

WANDB_USER = os.environ["WANDB_ENTITY"] or False
WANDB_KEY = os.environ["WANDB_API_KEY"] or False
WANDB_AVAIL = WANDB_USER and WANDB_KEY
if not WANDB_AVAIL:
    print("WANDB NON AVAIL, please set environment")
    exit(1)


def get_proj_runs(proj: str):
    api = wandb.Api()
    runs = api.runs(f"{WANDB_USER}/{proj}")
    return runs



import shutil

import typer
from loguru import logger

from jexp.hyd import (
    clear_empty,
    delete_run_from_folder,
    filter_hyd_stale,
    filter_hyd_wandb,
)


def clean_project(
    fname: str,
    inc_wandb: bool = typer.Option(False, "--w", help="delete not sync wandb folder"),
    delete_wandb: bool = typer.Option(False, "--r", help="delete wandb run"),
    delete: bool = typer.Option(False, "--d", help="delete exps"),
):
    for run in filter_hyd_stale(fname):
        if delete_wandb:
            delete_run_from_folder(run)
        if delete:
            shutil.rmtree(run, ignore_errors=True)

    if inc_wandb:
        for run in filter_hyd_wandb(fname):
            logger.info(f"WANDB NON SYNC: {run}")
            if delete:
                shutil.rmtree(run, ignore_errors=True)
    clear_empty()


def main():
    typer.run(clean_project)
